==> qtjambi-activex-debuginfo-windows-x64-6.5.3.jar: sources/QtJambiActiveX/QAxBaseWidget_shell.h <==
#ifndef QAXBASEWIDGET_SHELL_H
#define QAXBASEWIDGET_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <ActiveQt/qaxwidget.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qtguiglobal.h>
#if QT_CONFIG(action)
#include <QtGui/qaction.h>
#endif //QT_CONFIG(action)
#include <QtGui/qbackingstore.h>
#include <QtGui/qbitmap.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qfontinfo.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qicon.h>
#if QT_CONFIG(shortcut)
#include <QtGui/qkeysequence.h>
#endif //QT_CONFIG(shortcut)
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qwindow.h>
#include <qtwidgets-config.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsproxywidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/AboutToPaint>
#include <QtJambi/RegistryAPI>


class QAxBaseWidget_shell : public QAxBaseWidget, public QtJambiShellInterface
{
public:
    QAxBaseWidget_shell(QWidget* parent0 = nullptr, qint32 f1 = Qt::WindowFlags());
    ~QAxBaseWidget_shell() override;

    void actionEvent(QActionEvent* event0) override;
    void changeEvent(QEvent* arg__1) override;
    void childEvent(QChildEvent* event0) override;
    ulong classContext() const override;
    void closeEvent(QCloseEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void contextMenuEvent(QContextMenuEvent* event0) override;
    QString control() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void dragEnterEvent(QDragEnterEvent* event0) override;
    void dragLeaveEvent(QDragLeaveEvent* event0) override;
    void dragMoveEvent(QDragMoveEvent* event0) override;
    void dropEvent(QDropEvent* event0) override;
    void enterEvent(QEnterEvent* event0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void focusInEvent(QFocusEvent* event0) override;
    bool focusNextPrevChild(bool next0) override;
    void focusOutEvent(QFocusEvent* event0) override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int arg__1) const override;
    void hideEvent(QHideEvent* event0) override;
    void initPainter(QPainter* painter0) const override;
    void inputMethodEvent(QInputMethodEvent* arg__1) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const override;
    void keyPressEvent(QKeyEvent* event0) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void leaveEvent(QEvent* event0) override;
    int metric(QPaintDevice::PaintDeviceMetric arg__1) const override;
    QSize minimumSizeHint() const override;
    void mouseDoubleClickEvent(QMouseEvent* event0) override;
    void mouseMoveEvent(QMouseEvent* event0) override;
    void mousePressEvent(QMouseEvent* event0) override;
    void mouseReleaseEvent(QMouseEvent* event0) override;
    void moveEvent(QMoveEvent* event0) override;
    QPaintEngine* paintEngine() const override;
    void paintEvent(QPaintEvent* event0) override;
    QPaintDevice* redirected(QPoint* offset0) const override;
    void resetControl() override;
    void resizeEvent(QResizeEvent* event0) override;
    void setClassContext(ulong classContext0) override;
    bool setControl(const QString& c0) override;
    void setVisible(bool visible0) override;
    QPainter* sharedPainter() const override;
    void showEvent(QShowEvent* event0) override;
    QSize sizeHint() const override;
    void tabletEvent(QTabletEvent* event0) override;
    void timerEvent(QTimerEvent* event0) override;
    void wheelEvent(QWheelEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAxBaseWidget_access : public QAxBaseWidget
{
    jint __qt_classContext(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_control(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_resetControl(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_setClassContext_ulong(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint classContext0);
    jboolean __qt_setControl_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring c0);
};

#endif // QAXBASEWIDGET_SHELL_H

==> qtjambi-activex-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiActiveX/QAxBaseWidget_shell.h <==
#ifndef QAXBASEWIDGET_SHELL_H
#define QAXBASEWIDGET_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#if __has_include(<ActiveQt/qaxwidget.h>)
#include <ActiveQt/qaxwidget.h>
#endif
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qtguiglobal.h>
#if QT_CONFIG(action)
#include <QtGui/qaction.h>
#endif //QT_CONFIG(action)
#include <QtGui/qbackingstore.h>
#include <QtGui/qbitmap.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qfontinfo.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qicon.h>
#if QT_CONFIG(shortcut)
#include <QtGui/qkeysequence.h>
#endif //QT_CONFIG(shortcut)
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qwindow.h>
#include <qtwidgets-config.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsproxywidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/AboutToPaint>
#include <QtJambi/RegistryAPI>


#if defined(Q_OS_WIN)

class QAxBaseWidget_shell : public QAxBaseWidget, public QtJambiShellInterface
{
public:
    QAxBaseWidget_shell(QWidget* parent0 = nullptr, qint32 f1 = Qt::WindowFlags());
    ~QAxBaseWidget_shell() override;

    void actionEvent(QActionEvent* event0) override;
    void changeEvent(QEvent* arg__1) override;
    void childEvent(QChildEvent* event0) override;
    ulong classContext() const override;
    void closeEvent(QCloseEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void contextMenuEvent(QContextMenuEvent* event0) override;
    QString control() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void dragEnterEvent(QDragEnterEvent* event0) override;
    void dragLeaveEvent(QDragLeaveEvent* event0) override;
    void dragMoveEvent(QDragMoveEvent* event0) override;
    void dropEvent(QDropEvent* event0) override;
    void enterEvent(QEnterEvent* event0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void focusInEvent(QFocusEvent* event0) override;
    bool focusNextPrevChild(bool next0) override;
    void focusOutEvent(QFocusEvent* event0) override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int arg__1) const override;
    void hideEvent(QHideEvent* event0) override;
    void initPainter(QPainter* painter0) const override;
    void inputMethodEvent(QInputMethodEvent* arg__1) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const override;
    void keyPressEvent(QKeyEvent* event0) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void leaveEvent(QEvent* event0) override;
    int metric(QPaintDevice::PaintDeviceMetric arg__1) const override;
    QSize minimumSizeHint() const override;
    void mouseDoubleClickEvent(QMouseEvent* event0) override;
    void mouseMoveEvent(QMouseEvent* event0) override;
    void mousePressEvent(QMouseEvent* event0) override;
    void mouseReleaseEvent(QMouseEvent* event0) override;
    void moveEvent(QMoveEvent* event0) override;
    QPaintEngine* paintEngine() const override;
    void paintEvent(QPaintEvent* event0) override;
    QPaintDevice* redirected(QPoint* offset0) const override;
    void resetControl() override;
    void resizeEvent(QResizeEvent* event0) override;
    void setClassContext(ulong classContext0) override;
    bool setControl(const QString& c0) override;
    void setVisible(bool visible0) override;
    QPainter* sharedPainter() const override;
    void showEvent(QShowEvent* event0) override;
    QSize sizeHint() const override;
    void tabletEvent(QTabletEvent* event0) override;
    void timerEvent(QTimerEvent* event0) override;
    void wheelEvent(QWheelEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAxBaseWidget_access : public QAxBaseWidget
{
    jint __qt_classContext(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_control(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_resetControl(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_setClassContext_ulong(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint classContext0);
    jboolean __qt_setControl_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring c0);
};

#endif // defined(Q_OS_WIN)
#endif // QAXBASEWIDGET_SHELL_H
